@@ -15,40 +15,40 @@ from dateutil.relativedelta import relativedelta  # 安装 pip install python-da
 from retrying import retry
 
 
-def datetime_toStr(dt: datetime) -> str:
+def datetime_toStr(dt: datetime, fm: str = "%Y-%m-%d") -> str:
     """
     把datetime转成字符串
     :param dt: datetime.datetime.now
     :return: '2020-01-01'
     """
-    return dt.strftime("%Y-%m-%d")
+    return dt.strftime(fm)
 
 
-def datetime_toStr_dil(dt: datetime) -> str:
+def datetime_toStr_dil(dt: datetime, fm: str = "%Y-%m-%d %H:%M:%S") -> str:
     """
     把datetime转成字符串 详细版
     :param dt: datetime.datetime.now
     :return: '2020-01-01'
     """
-    return dt.strftime("%Y-%m-%d %H:%M:%S")
+    return dt.strftime(fm)
 
 
-def datetime_toChinStr(dt: datetime) -> str:
+def datetime_toChinStr(dt: datetime, fm: str = "%Y年%m月%d日") -> str:
     """
     把datetime转成中文字符串
     :param dt: datetime.datetime.now
     :return: '2020-01-01'
     """
-    return dt.strftime("%Y年%m月%d日")
+    return dt.strftime(fm)
 
 
-def datetime_toChinStr_dil(dt: datetime) -> str:
+def datetime_toChinStr_dil(dt: datetime, fm: str = "%Y年%m月%d日 %H时%M分%S秒") -> str:
     """
     把datetime转成字符串 详细版
     :param dt: datetime.datetime.now
     :return: '2020-01-01'
     """
-    return dt.strftime("%Y年%m月%d日 %H时%M分%S秒")
+    return dt.strftime(fm)
 
 
 def datetime_toCustStr(dt: datetime, fmat: str) -> str:
@@ -61,35 +61,38 @@ def datetime_toCustStr(dt: datetime, fmat: str) -> str:
     return dt.strftime(fmat)
 
 
-def get_now_date():
+def get_now_date(fm: str = "%Y-%m-%d"):
     """
     获取今日日期字符串
     :return:  '2020-01-01'
     """
-    return datetime.datetime.now().strftime("%Y-%m-%d")
+    return datetime.datetime.now().strftime(fm)
 
-def get_now_time():
+
+def get_now_time(fm: str = "%Y-%m-%d  %H:%M:%S"):
     """
     获取现在时间字符串
     :return:  '2020-01-01 15:29:08'
     """
-    return datetime.datetime.now().strftime("%Y-%m-%d  %H:%M:%S")
+    return datetime.datetime.now().strftime(fm)
 
-def str_toDatetime(str: str) -> datetime:
+
+def str_toDatetime(str: str, fm: str = "%Y-%m-%d") -> datetime:
     """
     把字符串转成datetime  精确到日
     :param str: '2020-01-01'
     :return:
     """
-    return datetime.datetime.strptime(str, "%Y-%m-%d")
+    return datetime.datetime.strptime(str, fm)
 
-def dil_str_toDatetime(str: str) -> datetime:
+
+def dil_str_toDatetime(str: str, fm: str = "%Y-%m-%d  %H:%M:%S") -> datetime:
     """
     把字符串转成datetime 精确到秒
     :param str: '2020-01-01'
     :return:
     """
-    return datetime.datetime.strptime(str, "%Y-%m-%d  %H:%M:%S")
+    return datetime.datetime.strptime(str, fm)
 
 
 def str_toTimestamp(strTime: str) -> int:
@@ -101,22 +104,22 @@ def str_toTimestamp(strTime: str) -> int:
     return int(time.mktime(str_toDatetime(strTime).timetuple()))
 
 
-def timestamp_tostr(stamp: int) -> str:
+def timestamp_tostr(stamp: int, fm: str = "%Y-%m-%d") -> str:
     """
     把时间戳转成字符串形式
     :param stamp: 1577808000
     :return: '2020-01-01'
     """
-    return time.strftime("%Y-%m-%d", time.localtime(stamp))
+    return time.strftime(fm, time.localtime(stamp))
 
 
-def ts_toStr_det(stamp: int) -> str:
+def ts_toStr_det(stamp: int, fm: str = "%Y-%m-%d  %H:%M:%S") -> str:
     """
     把时间戳转成字符串形式精确到秒
     :param stamp: 1577808000
     :return: '2020-01-01'
     """
-    return time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(stamp))
+    return time.strftime(fm, time.localtime(stamp))
 
 
 def datetime_toTimestamp(dateTime: datetime):
@@ -128,17 +131,17 @@ def datetime_toTimestamp(dateTime: datetime):
     return int(time.mktime(dateTime.timetuple()))
 
 
-def str_totime_dil(str_p: str):
+def str_totime_dil(str_p: str, fm: str = "%Y-%m-%d  %H:%M:%S"):
     """时间字符串转换成时间类型"""
     """2019-01-30 15:29:08"""
-    dateTime_p = datetime.datetime.strptime(str_p, '%Y-%m-%d %H:%M:%S')
+    dateTime_p = datetime.datetime.strptime(str_p, fm)
     return dateTime_p
 
 
-def str_totime(str_p: str):
+def str_totime(str_p: str, fm: str = "%Y-%m-%d"):
     """时间字符串转换成时间类型"""
     """2019-01-30"""
-    dateTime_p = datetime.datetime.strptime(str_p, '%Y-%m-%d')
+    dateTime_p = datetime.datetime.strptime(str_p, fm)
     return dateTime_p
 
 
@@ -203,6 +206,7 @@ def dateTime_Add(dateStr: str, days=0, hours=0, minutes=0) -> datetime:
     date1 = dil_str_toDatetime(dateStr)
     return date1 + datetime.timedelta(days=days, hours=hours, minutes=minutes)
 
+
 def date_time_subtraction(dateStr: str, days=0, hours=0, minutes=0) -> datetime:
     """
     指定日期减去 一个时间段，天，小时，或分钟之后的日期
@@ -215,7 +219,8 @@ def date_time_subtraction(dateStr: str, days=0, hours=0, minutes=0) -> datetime:
     date1 = dil_str_toDatetime(dateStr)
     return date1 - datetime.timedelta(days=days, hours=hours, minutes=minutes)
 
-def month_get(date:datetime):
+
+def month_get(date: datetime):
     """
     返回上个月第一个天和最后一天的日期时间
     date:datetime
@@ -229,6 +234,7 @@ def month_get(date:datetime):
     date_to = datetime.datetime(dayto.year, dayto.month, dayto.day, 23, 59, 59)
     return date_from, date_to
 
+
 def format_nowtime_millisecond() -> int:
     """
     获取毫秒级时间戳
@@ -354,6 +360,7 @@ def monitoring_run_time(f):
         end_time = time.time()
         print("%s执行成功，用时:%.2f" % (f.__name__, end_time - start_time))
         return res
+
     return wrapper
 
 
@@ -361,13 +368,13 @@ def monitoring_run_time(f):
 def get_taobao_time():
     """获取在线时间{"sysTime2":"2021-01-12 16:41:50","sysTime1":"20210112164150"}"""
     try:
-        url = 'http://10.228.84.20:21000/get_local_timestamp'
+        url = 'http://api.m.taobao.com/rest/api3.do?api=mtop.common.getTimestamp'
         ts = requests.get(url)
-        if ts.status_code == 200:
-            json_data = json.loads(ts.text)
-            return {"sysTime3": ts_toStr_det(json_data.get('time')),
-                    "sysTime2": timestamp_tostr(json_data.get('time')),
-                    "sysTime1": f"{json_data.get('time')}"}
+        if '调用成功' in ts.text:
+            json_data = ts.json()
+            return {"sysTime3": ts_toStr_det(json_data.get('data').get('t')),
+                    "sysTime2": timestamp_tostr(json_data.get('data').get('t')),
+                    "sysTime1": f"{json_data.get('data').get('t')}"}
         else:
             json_data = {"sysTime3": ts_toStr_det(int(time.time())),
                          "sysTime2": datetime_toStr(datetime.datetime.now()),
@@ -382,4 +389,4 @@ def get_taobao_time():
 
 if __name__ == '__main__':
     # month_begin_day = month_datelist('2020-01')
-    print(getdate(1))
+    print(get_taobao_time())
